from emitime.base import Interval, Moment
from typing import Any, Callable

class ParserRAM:
    def __init__(self, factory: Callable) -> None: ...
    def __call__(self, *args, **kwargs) -> Any: ...

class MomentParserRAM(ParserRAM):
    def __init__(self) -> None: ...
    def __call__(self, *args, **kwargs) -> Moment: ...

class IntervalParserRAM(ParserRAM):
    def __init__(self) -> None: ...
    def __call__(self, *args, **kwargs) -> Interval: ...
